==> KarnaughMap-1.0.1.tar.gz: KarnaughMap-1.0.1/README.md <==
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Issues][issues-shield]][issues-url]
<!--[![LinkedIn][linkedin-shield]][linkedin-url]-->



<br />
<p align="center">
  <a href="https://github.com/BizTecBritain/KarnaughMap">
    <img src="https://github.com/BizTecBritain/BizTecBritain/blob/main/BizTec.png" alt="Logo" width="580" height="300">
  </a>

  <h3 align="center">Karnaugh Maps</h3>

  <p align="center">
    Dependency-free library to create Karnaugh Map objects which can be solved and manipulated (GUI and CLI included)
    <br />
    <a href="https://github.com/BizTecBritain/KarnaughMap"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/BizTecBritain/KarnaughMap">View Demo</a>
    ·
    <a href="https://github.com/BizTecBritain/KarnaughMap/issues">Report Bug</a>
    ·
    <a href="https://github.com/BizTecBritain/KarnaughMap/issues">Request Feature</a>
  </p>
</p>



<details open="open">
  <summary><h2 style="display: inline-block">Table of Contents</h2></summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgements">Acknowledgements</a></li>
  </ol>
</details>



## About The Project

I was inspired by a topic that i was studying at school and so I made a program to solve Karnaugh maps


### Built With

* Python version >= 3.8
* may work with earlier versions but it is untested feel free to try it by downloading from my github [https://github.com/BizTecBritain/KarnaughMap](https://github.com/BizTecBritain/KarnaughMap)



## Getting Started

To get a local copy up and running follow these simple steps.

### Prerequisites

* Install git and python
  ```
   $ sudo apt-get update
   $ sudo apt-get install git
   $ sudo apt-get install python
  ```

* (Optional) Create virtual environment
  * #### Linux:
    ```
    $ python -m venv venv
    $ venv/bin/activate
    ```
  * #### Windows:
    ```
    > python -m venv venv
    > venv/Scripts/activate.bat
    ```

### Installation

Clone the repo with ```$ git clone https://github.com/BizTecBritain/KarnaughMap.git```



## Usage

First enter the directory with
```
$ cd src
```

Then to use this code as a GUI simply run
```
$ python main.py
```

_For more examples, please refer to the [Documentation](https://example.com)_



## Roadmap

See the [open issues](https://github.com/BizTecBritain/KarnaughMap/issues) for a list of proposed features (and known issues).



## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



## License

Distributed under the MIT License. See `LICENSE` for more information.



## Contact

Alexander Bisland - Twitter: [@BizTecBritain](https://twitter.com/BizTecBritain) - Email: BizTecBritain@gmail.com

Project Link: [https://github.com/BizTecBritain/KarnaughMap](https://github.com/BizTecBritain/KarnaughMap) 



## Acknowledgements

* Thanks to [othneildrew](https://github.com/othneildrew/Best-README-Template/blob/master/BLANK_README.md) for the blank README.md file

[contributors-shield]: https://img.shields.io/github/contributors/BizTecBritain/KarnaughMap.svg?style=for-the-badge
[contributors-url]: https://github.com/BizTecBritain/KarnaughMap/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/BizTecBritain/KarnaughMap.svg?style=for-the-badge
[forks-url]: https://github.com/BizTecBritain/KarnaughMap/network/members
[issues-shield]: https://img.shields.io/github/issues/BizTecBritain/KarnaughMap.svg?style=for-the-badge
[issues-url]: https://github.com/BizTecBritain/KarnaughMap/issues
<!--[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/othneildrew-->

==> KarnaughMap-1.1.0.tar.gz: KarnaughMap-1.1.0/README.md <==
[![Contributors][contributors-shield]][contributors-url]
[![Forks][forks-shield]][forks-url]
[![Issues][issues-shield]][issues-url]
<!--[![LinkedIn][linkedin-shield]][linkedin-url]-->



<br />
<p align="center">
  <a href="https://github.com/BizTecBritain/KarnaughMap">
    <img src="https://github.com/BizTecBritain/BizTecBritain/blob/main/BizTec.png?raw=true" alt="Logo" width="580" height="300">
  </a>

  <h3 align="center">Karnaugh Maps</h3>

  <p align="center">
    Dependency-free library to create Karnaugh Map objects which can be solved and manipulated (GUI and CLI included)
    <br />
    <a href="https://github.com/BizTecBritain/KarnaughMap"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/BizTecBritain/KarnaughMap">View Demo</a>
    ·
    <a href="https://github.com/BizTecBritain/KarnaughMap/issues">Report Bug</a>
    ·
    <a href="https://github.com/BizTecBritain/KarnaughMap/issues">Request Feature</a>
  </p>
</p>



<details open="open">
  <summary><h2 style="display: inline-block">Table of Contents</h2></summary>
  <ol>
    <li>
      <a href="#about-the-project">About The Project</a>
      <ul>
        <li><a href="#built-with">Built With</a></li>
      </ul>
    </li>
    <li>
      <a href="#getting-started">Getting Started</a>
      <ul>
        <li><a href="#prerequisites">Prerequisites</a></li>
        <li><a href="#installation">Installation</a></li>
      </ul>
    </li>
    <li><a href="#usage">Usage</a></li>
    <li><a href="#roadmap">Roadmap</a></li>
    <li><a href="#contributing">Contributing</a></li>
    <li><a href="#license">License</a></li>
    <li><a href="#contact">Contact</a></li>
    <li><a href="#acknowledgements">Acknowledgements</a></li>
  </ol>
</details>



## About The Project

I was inspired by a topic that I was studying at school and so I made a program to solve Karnaugh maps


### Built With

* Python version >= 3.8
* May work with earlier versions but it is untested feel free to try it by downloading from my github [https://github.com/BizTecBritain/KarnaughMap](https://github.com/BizTecBritain/KarnaughMap)



## Getting Started

To get a local copy up and running follow these simple steps.

### Prerequisites

* Install git and python
  ```
   $ sudo apt-get update
   $ sudo apt-get install git
   $ sudo apt-get install python
  ```

### Installation

Clone the repo with ```$ git clone https://github.com/BizTecBritain/KarnaughMap.git```
Or install with ```$ pip install KarnaughMap```



## Usage

This can be used as a library (see documentation) or run from the command line (you need to add to PATH)
* To run the standard command line interface run:
  ```
  $ KMap.exe expression [-h] [--print-map] [--debug] [--tot-input TOT_INPUT]
  
  positional arguments:
    expression            Unsimplified expression to simplify
  
  optional arguments:
    -h, --help            show this help message and exit
    --print-map, -p       Whether to print the map or not
    --debug, -d           Debug mode (verbose)
    --tot-input TOT_INPUT, -i TOT_INPUT
                          Total number of inputs (Optional)
  ```
* To run the GUI from the command line run:
  ```
  $ KMapGUI.exe
  ```

_For more examples, please refer to the [Documentation](https://example.com)_



## Roadmap

See the [open issues](https://github.com/BizTecBritain/KarnaughMap/issues) for a list of proposed features (and known issues).



## Contributing

Contributions are what make the open source community such an amazing place to be learn, inspire, and create. Any contributions you make are **greatly appreciated**.

1. Fork the Project
2. Create your Feature Branch (`git checkout -b feature/AmazingFeature`)
3. Commit your Changes (`git commit -m 'Add some AmazingFeature'`)
4. Push to the Branch (`git push origin feature/AmazingFeature`)
5. Open a Pull Request



## License

Distributed under the MIT License. See `LICENSE` for more information.



## Contact

Alexander Bisland - Twitter: [@BizTecBritain](https://twitter.com/BizTecBritain) - Email: BizTecBritain@gmail.com

Project Link: [https://github.com/BizTecBritain/KarnaughMap](https://github.com/BizTecBritain/KarnaughMap) 



## Acknowledgements

* Thanks to [othneildrew](https://github.com/othneildrew/Best-README-Template/blob/master/BLANK_README.md) for the blank README.md file

[contributors-shield]: https://img.shields.io/github/contributors/BizTecBritain/KarnaughMap.svg?style=for-the-badge
[contributors-url]: https://github.com/BizTecBritain/KarnaughMap/graphs/contributors
[forks-shield]: https://img.shields.io/github/forks/BizTecBritain/KarnaughMap.svg?style=for-the-badge
[forks-url]: https://github.com/BizTecBritain/KarnaughMap/network/members
[issues-shield]: https://img.shields.io/github/issues/BizTecBritain/KarnaughMap.svg?style=for-the-badge
[issues-url]: https://github.com/BizTecBritain/KarnaughMap/issues
<!--[linkedin-shield]: https://img.shields.io/badge/-LinkedIn-black.svg?style=for-the-badge&logo=linkedin&colorB=555
[linkedin-url]: https://linkedin.com/in/othneildrew-->
